pub struct GeneralViewMetadata<T>where
T: Materialization,{
pub view_uuid: Uuid,
pub format_version: FormatVersion,
pub location: String,
pub current_version_id: i64,
pub versions: HashMap<i64, Version<T>>,
pub version_log: Vec<VersionLogStruct>,
pub schemas: HashMap<i32, Schema>,
pub properties: HashMap<String, String>,
}Expand description
Fields for the version 1 of the view metadata.
Fields
view_uuid: UuidA UUID that identifies the view, generated when the view is created. Implementations must throw an exception if a view’s UUID does not match the expected UUID after refreshing metadata
format_version: FormatVersionAn integer version number for the view format; must be 1
location: StringThe view’s base location. This is used to determine where to store manifest files and view metadata files.
current_version_id: i64Current version of the view. Set to ‘1’ when the view is first created.
versions: HashMap<i64, Version<T>>An array of structs describing the last known versions of the view. Controlled by the table property: “version.history.num-entries”. See section Versions.
version_log: Vec<VersionLogStruct>A list of timestamp and version ID pairs that encodes changes to the current version for the view. Each time the current-version-id is changed, a new entry should be added with the last-updated-ms and the new current-version-id.
schemas: HashMap<i32, Schema>A list of schemas, the same as the ‘schemas’ field from Iceberg table spec.
properties: HashMap<String, String>A string to string map of view properties. This is used for metadata such as “comment” and for settings that affect view maintenance. This is not intended to be used for arbitrary metadata.
Implementations
Sourceimpl GeneralViewMetadata<Identifier>
impl GeneralViewMetadata<Identifier>
pub fn as_ref(&self) -> TabularMetadataRef<'_>
Sourceimpl<T> GeneralViewMetadata<T>where
T: Materialization,
impl<T> GeneralViewMetadata<T>where
T: Materialization,
Sourceimpl GeneralViewMetadata<Option<()>>
impl GeneralViewMetadata<Option<()>>
pub fn as_ref(&self) -> TabularMetadataRef<'_>